==> dasu_3.02.jar: edu/northwestern/dasu/stats/DownloadStatsDynamic.java <==
/**
 * Dasu Project
 *
 * File:         DownloadStats.java
 * RCS:          $Id$
 * Description:  DownloadStats class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 10, 2007 at 1:39:15 PM
 * Language:     Java
 * Package:      edu.northwestern.news.stats
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2007, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.stats;


import org.gudy.azureus2.core3.download.DownloadManager;
import org.gudy.azureus2.plugins.download.Download;
import org.gudy.azureus2.plugins.peers.Peer;
import org.gudy.azureus2.plugins.peers.PeerManager;

import edu.northwestern.dasu.Main;
import edu.northwestern.dasu.util.Util;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 *
 * downloadStatDynamic5
 */

public class DownloadStatsDynamic implements Cloneable {

	public long downloadId;
	public long timeRecorded;
	public int numPeers;
	public float availability;
	public int completed;
	public int discarded;
	public int downloadRate;
	public int shareRatio;
	public int uploadRate;
	public int numKnownNonSeeds;
	public int numKnownSeeds;
	public int totalNumKnownNonSeeds=-1;
	public int totalNumKnownSeeds=-1;
	public int state;
	public int priority;
	public long downloaded;
	public long uploaded;
	public int position;
	public long hashFails=0;
	public int numRst=0;
	public String downloadName = null;
	public int connectedSeeds=0;
	public int connectedLeechers=0;
	public int numPendingPeers=0;
	public long swarmPeerSpeed=-1;
	
	public DownloadStatsDynamic(Download download, int numRst) {

		downloadId = getId(download);
		timeRecorded = Util.currentGMTTime();
		availability = download.getStats().getAvailability();
		completed = download.getStats().getCompleted();
		discarded = (int) download.getStats().getDiscarded();
		hashFails = download.getStats().getHashFails();
		downloadRate = (int) download.getStats().getDownloadAverage();
		shareRatio = download.getStats().getShareRatio();
		uploadRate = (int) download.getStats().getUploadAverage();
		numKnownNonSeeds = download.getLastAnnounceResult().getNonSeedCount();
		numKnownSeeds = download.getLastAnnounceResult().getSeedCount();
		totalNumKnownNonSeeds = download.getLastScrapeResult().getNonSeedCount();
		totalNumKnownSeeds = download.getLastScrapeResult().getSeedCount();
		state = download.getState();
		priority = download.getIndex();
		position = download.getPosition();
		downloaded = download.getStats().getDownloaded();
		uploaded = download.getStats().getUploaded();
		downloadName = download.getName();

		for (Object obj : Main.getGlobalManager().getDownloadManagers()) {
			DownloadManager dm = (DownloadManager) obj;
			if (dm.getDisplayName().equals(download.getName()))
				swarmPeerSpeed = dm.getStats().getTotalAveragePerPeer();
		}
		
		PeerManager pm = download.getPeerManager();	
		if (pm!=null){
			numPeers = pm.getPeers().length;
			connectedSeeds =  download.getPeerManager().getStats().getConnectedSeeds();
			connectedLeechers = download.getPeerManager().getStats().getConnectedLeechers();			

			//numPendingPeers = pm.getPendingPeers().length;

			numPendingPeers = 0;
			for ( int i=0;i<pm.getPeers().length;i++){    			
    			Peer peer = pm.getPeers()[i];    			
    			String	key = peer.getIp();
    			numPendingPeers+=pm.getPendingPeers(key).length;
			}

			
		}
		this.numRst = numRst;
	}

	public DownloadStatsDynamic() {
		timeRecorded = Util.currentGMTTime();
	}

	public boolean contains(String s) {

		if (s.equals("downloadId") || s.equals("timeRecorded") || s.equals("numPeers") ||
				s.equals("availability") || s.equals("completed") || s.equals("discarded") ||
				s.equals("downloadRate")  || s.equals("shareRatio") || s.equals("uploadRate") ||
				s.equals("numKnownNonSeeds") || s.equals("numKnownSeeds") ||
				s.equals("totalNumKnownNonSeeds") || s.equals("totalNumKnownSeeds") ||
				s.equals("state") || s.equals("priority") || s.equals("downloaded") ||
				s.equals("uploaded") || s.equals("position") || s.equals("numOnoPeers") ||
				s.equals("hashFails") || s.equals("connectedSeeds") || s.equals("connectedLeechs") ||
				s.equals("numPendingPeers"))
			return true;
		
		return false;
			
	}

	private int getId(Download d) {
		return Main.getId(d);
	}
		
    public Object clone() {

      	 try {
                return super.clone();
            }
      	 catch( CloneNotSupportedException e ) {
                return null;
            }
        } 


}

==> dasu_4.11.jar: edu/northwestern/dasu/stats/DownloadStatsDynamic.java <==
/**
 * Dasu Project
 *
 * File:         DownloadStats.java
 * RCS:          $Id$
 * Description:  DownloadStats class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 10, 2007 at 1:39:15 PM
 * Language:     Java
 * Package:      edu.northwestern.news.stats
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2007, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.stats;


import java.lang.reflect.Field;

import org.gudy.azureus2.core3.download.DownloadManager;
import org.gudy.azureus2.plugins.download.Download;
import org.gudy.azureus2.plugins.peers.Peer;
import org.gudy.azureus2.plugins.peers.PeerManager;

import edu.northwestern.dasu.DasuManager;
import edu.northwestern.dasu.Main;
import edu.northwestern.dasu.util.Util;
import edu.northwestern.dasu.drools.FactTemplate;
import edu.northwestern.dasu.simulator.SimulatedDownload;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 *
 * downloadStatDynamic5
 */

public class DownloadStatsDynamic extends FactTemplate implements Cloneable  {

	public int downloadId;
	public long timeRecorded;
	public int numPeers;
	public float availability;
	public int completed;
	public int discarded;
	public int downloadRate;
	public int shareRatio;
	public int uploadRate;
	public int numKnownNonSeeds;
	public int numKnownSeeds;
	public int totalNumKnownNonSeeds=-1;
	public int totalNumKnownSeeds=-1;
	public int state;
	public int priority;
	public long downloaded;
	public long uploaded;
	public int position;
	public long hashFails=0;
	public int numRst=0;
	public String downloadName = null;
	public int connectedSeeds=0;
	public int connectedLeechers=0;
	public int numPendingPeers=0;
	public long swarmPeerSpeed=-1;

	public DownloadStatsDynamic(Download download, int numRst) {

		super();
		downloadId = getId(download);
		timeRecorded = Util.currentGMTTime();
		availability = download.getStats().getAvailability();
		completed = download.getStats().getCompleted();
		discarded = (int) download.getStats().getDiscarded();
		hashFails = download.getStats().getHashFails();			
		downloadRate = (int) download.getStats().getDownloadAverage();
		shareRatio = download.getStats().getShareRatio();
		uploadRate = (int) download.getStats().getUploadAverage();
		numKnownNonSeeds = download.getLastAnnounceResult().getNonSeedCount();
		numKnownSeeds = download.getLastAnnounceResult().getSeedCount();
		totalNumKnownNonSeeds = download.getLastScrapeResult().getNonSeedCount();
		totalNumKnownSeeds = download.getLastScrapeResult().getSeedCount();
		state = download.getState();
		priority = download.getIndex();
		position = download.getPosition();
		downloaded = download.getStats().getDownloaded();
		uploaded = download.getStats().getUploaded();
		downloadName = download.getName();

		if ( !DasuManager.USE_SIMULATION_V2) {

			for (Object obj : Main.getGlobalManager().getDownloadManagers()) {
				DownloadManager dm = (DownloadManager) obj;
				if (dm.getDisplayName().equals(download.getName())) {
					swarmPeerSpeed = dm.getStats().getTotalAveragePerPeer();
					break;
				}
			}
			
			PeerManager pm = download.getPeerManager();	
			if (pm!=null){
				numPeers = pm.getPeers().length;
				connectedSeeds =  download.getPeerManager().getStats().getConnectedSeeds();
				connectedLeechers = download.getPeerManager().getStats().getConnectedLeechers();			

				//numPendingPeers = pm.getPendingPeers().length;

				numPendingPeers = 0;
				for ( int i=0;i<pm.getPeers().length;i++){    			
	    			Peer peer = pm.getPeers()[i];    			
	    			String	key = peer.getIp();
	    			numPendingPeers+=pm.getPendingPeers(key).length;
				}
			}

		}
		else {
			
			swarmPeerSpeed = ((SimulatedDownload) download).swarmPeerSpeed;
			numPendingPeers = ((SimulatedDownload) download).numPendingPeers;
			numPeers = download.getPeerManager().getPeers().length;
			connectedSeeds =  download.getPeerManager().getStats().getConnectedSeeds();
			connectedLeechers = download.getPeerManager().getStats().getConnectedLeechers();			
		}
		
		this.numRst = numRst;
		
	}
	
	public DownloadStatsDynamic() {
		timeRecorded = Util.currentGMTTime();
	}

	public boolean contains(String s) {

		if (s.equals("downloadId") || s.equals("timeRecorded") || s.equals("numPeers") ||
				s.equals("availability") || s.equals("completed") || s.equals("discarded") ||
				s.equals("downloadRate")  || s.equals("shareRatio") || s.equals("uploadRate") ||
				s.equals("numKnownNonSeeds") || s.equals("numKnownSeeds") ||
				s.equals("totalNumKnownNonSeeds") || s.equals("totalNumKnownSeeds") ||
				s.equals("state") || s.equals("priority") || s.equals("downloaded") ||
				s.equals("uploaded") || s.equals("position") || s.equals("numOnoPeers") ||
				s.equals("hashFails") || s.equals("connectedSeeds") || s.equals("connectedLeechs") ||
				s.equals("numPendingPeers"))
			return true;
		
		return false;
			
	}

	private int getId(Download d) {
		return Main.getId(d);
	}
		
    public Object clone() {

      	 try {
                return super.clone();
            }
      	 catch( CloneNotSupportedException e ) {
                return null;
            }
        } 

    @Override
    public String toString() {
    	
    	String ret = "DownloadStatsDynamic: <";
    	try {
        	
    		for ( Field f : this.getClass().getFields()) {
    		
    			if ( f.get(this) != null)
    				ret = ret.concat(f.getName() + ": " + f.get(this).toString() + " ");
    		}
    		
    	} catch (Exception e) {
    		e.printStackTrace();
    	}
    	
    	ret = ret.concat(">");
    	return ret;
    }

}
